"""DO NOT EDIT.

This file was autogenerated. Do not edit it by hand,
since your modifications would be overwritten.
"""


from keras.src.utils.tree import assert_same_structure
from keras.src.utils.tree import flatten
from keras.src.utils.tree import is_nested
from keras.src.utils.tree import lists_to_tuples
from keras.src.utils.tree import map_structure
from keras.src.utils.tree import map_structure_up_to
from keras.src.utils.tree import pack_sequence_as
from keras.src.utils.tree import traverse
from keras.src.utils.tree import unflatten_as
